Index: main/waeup.uniben/trunk/src/waeup/uniben/applicants/browser_templates/applicantdisplaypage.pt
===================================================================
--- main/waeup.uniben/trunk/src/waeup/uniben/applicants/browser_templates/applicantdisplaypage.pt	(revision 10375)
+++ main/waeup.uniben/trunk/src/waeup/uniben/applicants/browser_templates/applicantdisplaypage.pt	(revision 10375)
@@ -0,0 +1,101 @@
+<h2 i18n:domain="waeup.kofa">
+  ...
+  <span tal:replace="context/translated_state">APPLICATIONSTATE
+  </span>
+  <span tal:omit-tag=""
+    i18n:translate="" tal:condition="context/suspended">(account suspended)
+  </span>
+  ...
+</h2>
+
+<h4 tal:condition="view/show_pastq_al">
+  Download past questions
+  <a href="https://uniben.waeup.org/downloads/ArtsAndLaw.pdf"
+      i18n:translate="">
+    'Arts And Law'
+  </a>
+   to exercise.
+</h4>
+
+<h4 tal:condition="view/show_pastq_bs">
+  Download past questions
+  <a href="https://uniben.waeup.org/downloads/BiologicalSciences.pdf"
+      i18n:translate="">
+    'Biological Sciences'
+  </a>
+   to exercise.
+</h4>
+
+<h4 tal:condition="view/show_pastq_eps">
+  Download past questions
+  <a href="https://uniben.waeup.org/downloads/EngineeringAndPhysicalSciences.pdf"
+      i18n:translate="">
+    'Engineering And Physical Sciences'
+  </a>
+   to exercise.
+</h4>
+
+<div class="workflow">
+  <div tal:repeat="msg context/history/messages">
+    <span tal:replace="msg">MESSAGE</span><br />
+  </div>
+</div>
+
+<img src="" height="180px" tal:attributes="src view/passport_url" />
+
+<h4 tal:condition="view/show_pastq_mss">
+  Download past questions
+  <a href="https://uniben.waeup.org/downloads/ManagementAndSocialSciences.pdf"
+      i18n:translate="">
+    'Management And Social Sciences'
+  </a>
+   to exercise.
+</h4>
+
+<table i18n:domain="waeup.kofa" class="form-table">
+  <tbody>
+    <tal:widgets content="structure provider:widgets" />
+    <tr tal:condition="view/getCourseAdmitted">
+      <td class="fieldname" i18n:translate="">
+          Admitted Course of Study:
+      </td>
+      <td>
+        <span tal:replace="structure view/getCourseAdmitted" />
+      </td>
+    </tr>
+    <tr>
+      <td class="fieldname" i18n:translate="">
+          Password:
+      </td>
+      <td>
+          <tal:password replace="view/hasPassword" />
+      </td>
+    <tr>
+  </tbody>
+</table>
+<h3  i18n:domain="waeup.kofa" i18n:translate="">
+    Application Fee Payment Tickets
+</h3>
+<table i18n:domain="waeup.kofa">
+  <thead>
+    <tr>
+      <th i18n:translate="">Payment Id</th>
+      <th i18n:translate="">Creation Date</th>
+      <th i18n:translate="">Payment Date</th>
+      <th i18n:translate="">Category</th>
+      <th i18n:translate="">Item</th>
+      <th i18n:translate="">State</th>
+    </tr>
+  </thead>
+  <tbody>
+    <tr tal:repeat="value context/values">
+      <td> <a tal:attributes="href value/__name__">
+      <span tal:content="value/p_id">PID</span></a></td>
+      <td tal:content="python: layout.formatDatetime(value.creation_date)">CREATION DATE</td>
+      <td tal:content="python: layout.formatDatetime(value.payment_date)">PAYMENT DATE</td>
+      <td tal:content ="value/category">CATEGORY</td>
+      <td tal:content ="value/display_item">ITEM</td>
+      <td tal:content ="value/p_state_title">STATE</td>
+    </tr>
+  </tbody>
+</table>
Index: main/waeup.uniben/trunk/src/waeup/uniben/applicants/browser_templates/applicanteditpage.pt
===================================================================
--- main/waeup.uniben/trunk/src/waeup/uniben/applicants/browser_templates/applicanteditpage.pt	(revision 10374)
+++ 	(revision )
@@ -1,160 +1,0 @@
-<form action="." tal:attributes="action request/URL" method="post"
-      i18n:domain="waeup.kofa" enctype="multipart/form-data"
-      autocomplete="off">
-
-  <h2 i18n:domain="waeup.kofa">
-    ...
-    <span tal:replace="context/translated_state">APPLICATIONSTATE
-    </span>
-    <span tal:omit-tag=""
-      i18n:translate="" tal:condition="context/suspended">(account suspended)
-    </span>
-    ...
-  </h2>
-
-  <div class="workflow">
-    <div tal:repeat="msg context/history/messages">
-      <span tal:replace="msg">MESSAGE</span><br />
-    </div>
-  </div>
-
-  <h4 tal:condition="view/show_pastq_al">
-    Download past questions
-    <a href="https://uniben.waeup.org/downloads/ArtsAndLaw.pdf"
-        i18n:translate="">
-      'Arts And Law'
-    </a>
-     to exercise.
-  </h4>
-
-  <h4 tal:condition="view/show_pastq_bs">
-    Download past questions
-    <a href="https://uniben.waeup.org/downloads/BiologicalSciences.pdf"
-        i18n:translate="">
-      'Biological Sciences'
-    </a>
-     to exercise.
-  </h4>
-
-  <h4 tal:condition="view/show_pastq_eps">
-    Download past questions
-    <a href="https://uniben.waeup.org/downloads/EngineeringAndPhysicalSciences.pdf"
-        i18n:translate="">
-      'Engineering And Physical Sciences'
-    </a>
-     to exercise.
-  </h4>
-
-  <h4 tal:condition="view/show_pastq_mss">
-    Download past questions
-    <a href="https://uniben.waeup.org/downloads/ManagementAndSocialSciences.pdf"
-        i18n:translate="">
-      'Management And Social Sciences'
-    </a>
-     to exercise.
-  </h4>
-
-  <table class="form-table">
-    <tbody>
-      <tal:widgets content="structure provider:widgets" />
-      <tr>
-        <td class="fieldname" i18n:translate="">
-          Passport Photo:
-        </td>
-        <td>
-          <img src="passport.jpg" height="180px" /><br />
-          <input type="file" name="form.passport" />
-          <br />
-          <span i18n:translate="">
-            Max. file size:
-          </span>
-          <span tal:replace="view/max_upload_size">10 KB</span>
-      </tr>
-      <tr tal:condition="view/manage_applications">
-        <td class="fieldname" i18n:translate="">Password:</td>
-        <td>
-          <input name="password" type="password"  />
-        </td>
-      </tr>
-      <tr tal:condition="view/manage_applications">
-        <td class="fieldname" i18n:translate="">Retype Password:</td>
-        <td>
-          <input name="control_password" type="password" />
-        </td>
-      </tr>
-      <tr tal:condition="view/manage_applications">
-        <td class="fieldname" i18n:translate="">Application Transition:</td>
-        <td>
-          <select id="transition" name="transition">
-            <option tal:repeat="transition view/getTransitions"
-                    tal:attributes="value transition/name">
-              <span tal:replace="transition/title">TRANSITIONTITLE</span>
-            </option>
-          </select>
-        </td>
-      </tr>
-    </tbody>
-  </table>
-
-  <div tal:condition="not: view/manage_applications">
-    <input id="confirm_passport" name="confirm_passport"
-           type="checkbox" value="True"/>
-    <span i18n:translate="">
-    I confirm that the Passport Photograph uploaded on this form is a
-    true picture of me.
-    </span>
-  </div>
-  <br />
-
-  <div tal:condition="view/availableActions">
-    <span tal:repeat="action view/actions"
-          tal:omit-tag="">
-      <input tal:condition="python:action.label in view.display_actions[0]"
-             tal:replace="structure action/render"/>
-    </span>
-  </div>
-
-  <br /><br />
-  <h3 i18n:translate="">
-      Acceptance Fee Payment Tickets
-  </h3>
-
-  <table>
-    <thead>
-    <tr>
-      <th>&nbsp;</th>
-      <th i18n:translate="">Payment Id</th>
-      <th i18n:translate="">Creation Date</th>
-      <th i18n:translate="">Payment Date</th>
-      <th i18n:translate="">Category</th>
-      <th i18n:translate="">Item</th>
-      <th i18n:translate="">State</th>
-    </tr>
-    </thead>
-    <tbody>
-      <tr tal:repeat="cl context/values">
-         <td>
-          <input type="checkbox"
-    		 name="val_id"
-    		 tal:attributes="value cl/__name__"
-         tal:condition="python: not view.unremovable(cl)" />
-        </td>
-        <td> <a tal:attributes="href cl/__name__">
-        <span tal:content="cl/p_id">PID</span></a></td>
-        <td tal:content="python: layout.formatDatetime(cl.creation_date)">CREATION DATE</td>
-        <td tal:content="python: layout.formatDatetime(cl.payment_date)">PAYMENT DATE</td>
-      <td tal:content ="cl/category">CATEGORY</td>
-      <td tal:content ="cl/display_item">ITEM</td>
-      <td tal:content ="cl/p_state_title">STATE</td>
-      </tr>
-    </tbody>
-  </table>
-
-  <div tal:condition="view/availableActions">
-    <span tal:repeat="action view/actions"
-          tal:omit-tag="">
-      <input tal:condition="python:action.label in view.display_actions[1]"
-             tal:replace="structure action/render"/>
-    </span>
-  </div>
-</form>

Index: main/waeup.uniben/trunk/src/waeup/uniben/applicants/browser.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/uniben/applicants/browser.py	(revision 10374)
+++ main/waeup.uniben/trunk/src/waeup/uniben/applicants/browser.py	(revision 10375)
@@ -20,5 +20,5 @@
 import grok
 from waeup.kofa.applicants.browser import ApplicantRegistrationPage
-from kofacustom.nigeria.applicants.browser import NigeriaApplicantEditFormPage
+from kofacustom.nigeria.applicants.browser import NigeriaApplicantDisplayFormPage
 
 PASTQ_ALL = ['ADT','EPCS','ESM','HEK','VTE']
@@ -49,12 +49,12 @@
         return
 
-class CustomApplicantEditFormPage(NigeriaApplicantEditFormPage):
-    """A full edit view for applicant data.
+class CustomApplicantDisplayFormPage(NigeriaApplicantDisplayFormPage):
+    """A display view for applicant data.
     """
-    grok.template('applicanteditpage')
+    grok.template('applicantdisplaypage')
 
     def _show_pastq(self):
         return self.target.startswith('putme') \
-               and self.context.state == 'paid' \
+               and self.context.state in ('paid', 'submitted') \
                and getattr(self.context, 'course1') is not None
 